div.collective-sylvester-dashboard-navigation a.collective-sylvester-replies {
    background-image: url(++resource++collective.sylvester.replies.png);
    background-repeat: no-repeat;
}

span.collective-sylvester-replies-subheading {
    color: #333333;
    font-size: 1.5em;  
}
