div.collective-sylvester-dashboard-navigation a.collective-sylvester-directmessages{
    background-image: url(++resource++collective.sylvester.directmessages.png);
    background-repeat: no-repeat;
}
